@@ -3,29 +3,6 @@ from discord.ui import View, Button
 from discord import ButtonStyle
 from typing import Union
 
-'''
- Copyright (c) 2022 Fadix47
-
- Permission is hereby granted, free of charge, to any person obtaining
- a copy of this software and associated documentation files (the
- "Software"), to deal in the Software without restriction, including
- without limitation the rights to use, copy, modify, merge, publish,
- distribute, sublicense, and/or sell copies of the Software, and to
- permit persons to whom the Software is furnished to do so, subject to
- the following conditions:
-
- The above copyright notice and this permission notice shall be included
- in all copies or substantial portions of the Software.
-
- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
- CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
- TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
- SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-'''
-
 locales = {
     "NEXT": {
         "en": "Next",
@@ -171,7 +148,6 @@ class Faginator(View):
 
             async def back_callback(interaction):
                 if check(interaction, view):
-                    await interaction.response.defer()
                     view.next_button.disabled = False
                     view.skip_end_button.disabled = False
                     view.skip_start_button.disabled = False
@@ -194,7 +170,6 @@ class Faginator(View):
 
             async def next_callback(interaction):
                 if check(interaction, view):
-                    await interaction.response.defer()
                     view.back_button.disabled = False
                     view.skip_end_button.disabled = False
                     view.skip_start_button.disabled = False
@@ -223,7 +198,6 @@ class Faginator(View):
 
             async def skip_start_callback(interaction):
                 if check(interaction, view):
-                    await interaction.response.defer()
                     view.skip_start_button.disabled = True
                     view.skip_end_button.disabled = False
 
@@ -243,7 +217,6 @@ class Faginator(View):
 
             async def skip_end_callback(interaction):
                 if check(interaction, view):
-                    await interaction.response.defer()
                     view.skip_end_button.disabled = True
                     view.skip_start_button.disabled = False
 
